@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2019 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -127,6 +127,9 @@ namespace KeePass.App
 			// public static readonly string FaqTechMemProt = "memprot";
 
 			public static readonly string XmlReplace = "v2/xml_replace";
+
+			public static readonly string KbFaq = "kb/faq";
+			public static readonly string KbFaqURtf = "urtf";
 		}
 
 		public static class CommandLineOptions
