@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2019 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,11 +19,11 @@
 
 using System;
 using System.Collections.Generic;
+using System.ComponentModel;
+using System.Diagnostics;
 using System.Text;
 using System.Windows.Forms;
 using System.Xml.Serialization;
-using System.ComponentModel;
-using System.Diagnostics;
 
 using KeePassLib;
 using KeePassLib.Interfaces;
@@ -233,6 +233,7 @@ namespace KeePass.App.Configuration
 		}
 
 		private ProxyServerType m_pstProxyType = ProxyServerType.System;
+		[DefaultValue(ProxyServerType.System)]
 		public ProxyServerType ProxyType
 		{
 			get { return m_pstProxyType; }
@@ -264,6 +265,7 @@ namespace KeePass.App.Configuration
 		}
 
 		private ProxyAuthType m_pstProxyAuthType = ProxyAuthType.Auto;
+		[DefaultValue(ProxyAuthType.Auto)]
 		public ProxyAuthType ProxyAuthType
 		{
 			get { return m_pstProxyAuthType; }
