@@ -169,7 +169,7 @@
 			this.m_lblUserName.Name = "m_lblUserName";
 			this.m_lblUserName.Size = new System.Drawing.Size(61, 13);
 			this.m_lblUserName.TabIndex = 4;
-			this.m_lblUserName.Text = "User name:";
+			this.m_lblUserName.Text = "&User name:";
 			// 
 			// m_lblPassword
 			// 
@@ -178,7 +178,7 @@
 			this.m_lblPassword.Name = "m_lblPassword";
 			this.m_lblPassword.Size = new System.Drawing.Size(56, 13);
 			this.m_lblPassword.TabIndex = 6;
-			this.m_lblPassword.Text = "Password:";
+			this.m_lblPassword.Text = "&Password:";
 			// 
 			// m_lblTitle
 			// 
@@ -186,8 +186,8 @@
 			this.m_lblTitle.Location = new System.Drawing.Point(6, 13);
 			this.m_lblTitle.Name = "m_lblTitle";
 			this.m_lblTitle.Size = new System.Drawing.Size(30, 13);
-			this.m_lblTitle.TabIndex = 1;
-			this.m_lblTitle.Text = "Title:";
+			this.m_lblTitle.TabIndex = 0;
+			this.m_lblTitle.Text = "&Title:";
 			// 
 			// m_lblPasswordRepeat
 			// 
@@ -196,7 +196,7 @@
 			this.m_lblPasswordRepeat.Name = "m_lblPasswordRepeat";
 			this.m_lblPasswordRepeat.Size = new System.Drawing.Size(45, 13);
 			this.m_lblPasswordRepeat.TabIndex = 9;
-			this.m_lblPasswordRepeat.Text = "Repeat:";
+			this.m_lblPasswordRepeat.Text = "&Repeat:";
 			// 
 			// m_lblUrl
 			// 
@@ -205,7 +205,7 @@
 			this.m_lblUrl.Name = "m_lblUrl";
 			this.m_lblUrl.Size = new System.Drawing.Size(32, 13);
 			this.m_lblUrl.TabIndex = 15;
-			this.m_lblUrl.Text = "URL:";
+			this.m_lblUrl.Text = "UR&L:";
 			// 
 			// m_lblNotes
 			// 
@@ -214,7 +214,7 @@
 			this.m_lblNotes.Name = "m_lblNotes";
 			this.m_lblNotes.Size = new System.Drawing.Size(38, 13);
 			this.m_lblNotes.TabIndex = 17;
-			this.m_lblNotes.Text = "Notes:";
+			this.m_lblNotes.Text = "&Notes:";
 			// 
 			// m_lblQuality
 			// 
@@ -230,7 +230,7 @@
 			this.m_tbTitle.Location = new System.Drawing.Point(81, 10);
 			this.m_tbTitle.Name = "m_tbTitle";
 			this.m_tbTitle.Size = new System.Drawing.Size(293, 20);
-			this.m_tbTitle.TabIndex = 0;
+			this.m_tbTitle.TabIndex = 1;
 			// 
 			// m_btnIcon
 			// 
@@ -248,7 +248,7 @@
 			this.m_lblIcon.Name = "m_lblIcon";
 			this.m_lblIcon.Size = new System.Drawing.Size(31, 13);
 			this.m_lblIcon.TabIndex = 2;
-			this.m_lblIcon.Text = "Icon:";
+			this.m_lblIcon.Text = "&Icon:";
 			// 
 			// m_tbUserName
 			// 
@@ -285,7 +285,7 @@
 			this.m_cbExpires.Name = "m_cbExpires";
 			this.m_cbExpires.Size = new System.Drawing.Size(63, 17);
 			this.m_cbExpires.TabIndex = 19;
-			this.m_cbExpires.Text = "Expires:";
+			this.m_cbExpires.Text = "&Expires:";
 			this.m_cbExpires.UseVisualStyleBackColor = true;
 			// 
 			// m_dtExpireDateTime
@@ -543,7 +543,7 @@
 			this.m_btnBinOpen.Name = "m_btnBinOpen";
 			this.m_btnBinOpen.Size = new System.Drawing.Size(75, 23);
 			this.m_btnBinOpen.TabIndex = 3;
-			this.m_btnBinOpen.Text = "O&pen";
+			this.m_btnBinOpen.Text = "Ope&n";
 			this.m_btnBinOpen.UseVisualStyleBackColor = true;
 			this.m_btnBinOpen.Click += new System.EventHandler(this.OnBtnBinOpen);
 			// 
@@ -573,7 +573,7 @@
 			this.m_btnBinAdd.Name = "m_btnBinAdd";
 			this.m_btnBinAdd.Size = new System.Drawing.Size(75, 23);
 			this.m_btnBinAdd.TabIndex = 1;
-			this.m_btnBinAdd.Text = "Attac&h";
+			this.m_btnBinAdd.Text = "A&ttach";
 			this.m_btnBinAdd.UseVisualStyleBackColor = true;
 			this.m_btnBinAdd.Click += new System.EventHandler(this.OnBtnBinAdd);
 			// 
@@ -712,7 +712,7 @@
 			this.m_lblCustomData.Name = "m_lblCustomData";
 			this.m_lblCustomData.Size = new System.Drawing.Size(63, 13);
 			this.m_lblCustomData.TabIndex = 8;
-			this.m_lblCustomData.Text = "Plugin data:";
+			this.m_lblCustomData.Text = "&Plugin data:";
 			// 
 			// m_btnCDDel
 			// 
@@ -761,7 +761,7 @@
 			this.m_lblTags.Name = "m_lblTags";
 			this.m_lblTags.Size = new System.Drawing.Size(34, 13);
 			this.m_lblTags.TabIndex = 4;
-			this.m_lblTags.Text = "Tags:";
+			this.m_lblTags.Text = "&Tags:";
 			// 
 			// m_btnPickFgColor
 			// 
@@ -779,7 +779,7 @@
 			this.m_cbCustomForegroundColor.Name = "m_cbCustomForegroundColor";
 			this.m_cbCustomForegroundColor.Size = new System.Drawing.Size(144, 17);
 			this.m_cbCustomForegroundColor.TabIndex = 0;
-			this.m_cbCustomForegroundColor.Text = "Custom foreground color:";
+			this.m_cbCustomForegroundColor.Text = "Custom &foreground color:";
 			this.m_cbCustomForegroundColor.UseVisualStyleBackColor = true;
 			this.m_cbCustomForegroundColor.CheckedChanged += new System.EventHandler(this.OnCustomForegroundColorCheckedChanged);
 			// 
@@ -798,7 +798,7 @@
 			this.m_lblUuid.Name = "m_lblUuid";
 			this.m_lblUuid.Size = new System.Drawing.Size(37, 13);
 			this.m_lblUuid.TabIndex = 11;
-			this.m_lblUuid.Text = "UUID:";
+			this.m_lblUuid.Text = "&UUID:";
 			// 
 			// m_lblOverrideUrl
 			// 
@@ -807,7 +807,7 @@
 			this.m_lblOverrideUrl.Name = "m_lblOverrideUrl";
 			this.m_lblOverrideUrl.Size = new System.Drawing.Size(222, 13);
 			this.m_lblOverrideUrl.TabIndex = 6;
-			this.m_lblOverrideUrl.Text = "Override URL (e.g. to use a specific browser):";
+			this.m_lblOverrideUrl.Text = "O&verride URL (e.g. to use a specific browser):";
 			// 
 			// m_cbCustomBackgroundColor
 			// 
@@ -816,7 +816,7 @@
 			this.m_cbCustomBackgroundColor.Name = "m_cbCustomBackgroundColor";
 			this.m_cbCustomBackgroundColor.Size = new System.Drawing.Size(150, 17);
 			this.m_cbCustomBackgroundColor.TabIndex = 2;
-			this.m_cbCustomBackgroundColor.Text = "Custom background color:";
+			this.m_cbCustomBackgroundColor.Text = "Custom &background color:";
 			this.m_cbCustomBackgroundColor.UseVisualStyleBackColor = true;
 			this.m_cbCustomBackgroundColor.CheckedChanged += new System.EventHandler(this.OnCustomBackgroundColorCheckedChanged);
 			// 
@@ -855,7 +855,7 @@
 			// m_btnAutoTypeDown
 			// 
 			this.m_btnAutoTypeDown.Image = global::KeePass.Properties.Resources.B16x16_1DownArrow;
-			this.m_btnAutoTypeDown.Location = new System.Drawing.Point(382, 282);
+			this.m_btnAutoTypeDown.Location = new System.Drawing.Point(382, 285);
 			this.m_btnAutoTypeDown.Name = "m_btnAutoTypeDown";
 			this.m_btnAutoTypeDown.Size = new System.Drawing.Size(75, 23);
 			this.m_btnAutoTypeDown.TabIndex = 11;
@@ -865,7 +865,7 @@
 			// m_btnAutoTypeUp
 			// 
 			this.m_btnAutoTypeUp.Image = global::KeePass.Properties.Resources.B16x16_1UpArrow;
-			this.m_btnAutoTypeUp.Location = new System.Drawing.Point(382, 253);
+			this.m_btnAutoTypeUp.Location = new System.Drawing.Point(382, 256);
 			this.m_btnAutoTypeUp.Name = "m_btnAutoTypeUp";
 			this.m_btnAutoTypeUp.Size = new System.Drawing.Size(75, 23);
 			this.m_btnAutoTypeUp.TabIndex = 10;
@@ -875,7 +875,7 @@
 			// m_linkAutoTypeObfuscation
 			// 
 			this.m_linkAutoTypeObfuscation.AutoSize = true;
-			this.m_linkAutoTypeObfuscation.Location = new System.Drawing.Point(208, 314);
+			this.m_linkAutoTypeObfuscation.Location = new System.Drawing.Point(208, 317);
 			this.m_linkAutoTypeObfuscation.Name = "m_linkAutoTypeObfuscation";
 			this.m_linkAutoTypeObfuscation.Size = new System.Drawing.Size(68, 13);
 			this.m_linkAutoTypeObfuscation.TabIndex = 13;
@@ -886,11 +886,11 @@
 			// m_cbAutoTypeObfuscation
 			// 
 			this.m_cbAutoTypeObfuscation.AutoSize = true;
-			this.m_cbAutoTypeObfuscation.Location = new System.Drawing.Point(9, 313);
+			this.m_cbAutoTypeObfuscation.Location = new System.Drawing.Point(9, 316);
 			this.m_cbAutoTypeObfuscation.Name = "m_cbAutoTypeObfuscation";
 			this.m_cbAutoTypeObfuscation.Size = new System.Drawing.Size(193, 17);
 			this.m_cbAutoTypeObfuscation.TabIndex = 12;
-			this.m_cbAutoTypeObfuscation.Text = "Two-channel auto-type obfuscation";
+			this.m_cbAutoTypeObfuscation.Text = "&Two-channel auto-type obfuscation";
 			this.m_cbAutoTypeObfuscation.UseVisualStyleBackColor = true;
 			this.m_cbAutoTypeObfuscation.CheckedChanged += new System.EventHandler(this.OnAutoTypeObfuscationCheckedChanged);
 			// 
@@ -912,7 +912,7 @@
 			this.m_rbAutoTypeOverride.Size = new System.Drawing.Size(153, 17);
 			this.m_rbAutoTypeOverride.TabIndex = 2;
 			this.m_rbAutoTypeOverride.TabStop = true;
-			this.m_rbAutoTypeOverride.Text = "Override default sequence:";
+			this.m_rbAutoTypeOverride.Text = "O&verride default sequence:";
 			this.m_rbAutoTypeOverride.UseVisualStyleBackColor = true;
 			// 
 			// m_rbAutoTypeSeqInherit
@@ -923,7 +923,7 @@
 			this.m_rbAutoTypeSeqInherit.Size = new System.Drawing.Size(239, 17);
 			this.m_rbAutoTypeSeqInherit.TabIndex = 1;
 			this.m_rbAutoTypeSeqInherit.TabStop = true;
-			this.m_rbAutoTypeSeqInherit.Text = "Inherit default auto-type sequence from group";
+			this.m_rbAutoTypeSeqInherit.Text = "&Inherit default auto-type sequence from group";
 			this.m_rbAutoTypeSeqInherit.UseVisualStyleBackColor = true;
 			this.m_rbAutoTypeSeqInherit.CheckedChanged += new System.EventHandler(this.OnAutoTypeSeqInheritCheckedChanged);
 			// 
@@ -934,7 +934,7 @@
 			this.m_lblCustomAutoType.Name = "m_lblCustomAutoType";
 			this.m_lblCustomAutoType.Size = new System.Drawing.Size(219, 13);
 			this.m_lblCustomAutoType.TabIndex = 5;
-			this.m_lblCustomAutoType.Text = "Use custom sequences for specific windows:";
+			this.m_lblCustomAutoType.Text = "&Use custom sequences for specific windows:";
 			// 
 			// m_cbAutoTypeEnabled
 			// 
@@ -943,7 +943,7 @@
 			this.m_cbAutoTypeEnabled.Name = "m_cbAutoTypeEnabled";
 			this.m_cbAutoTypeEnabled.Size = new System.Drawing.Size(166, 17);
 			this.m_cbAutoTypeEnabled.TabIndex = 0;
-			this.m_cbAutoTypeEnabled.Text = "Enable auto-type for this entry";
+			this.m_cbAutoTypeEnabled.Text = "E&nable auto-type for this entry";
 			this.m_cbAutoTypeEnabled.UseVisualStyleBackColor = true;
 			this.m_cbAutoTypeEnabled.CheckedChanged += new System.EventHandler(this.OnAutoTypeEnableCheckedChanged);
 			// 
@@ -993,7 +993,7 @@
 			this.m_lvAutoType.Location = new System.Drawing.Point(9, 134);
 			this.m_lvAutoType.Name = "m_lvAutoType";
 			this.m_lvAutoType.ShowItemToolTips = true;
-			this.m_lvAutoType.Size = new System.Drawing.Size(367, 170);
+			this.m_lvAutoType.Size = new System.Drawing.Size(367, 173);
 			this.m_lvAutoType.TabIndex = 6;
 			this.m_lvAutoType.UseCompatibleStateImageBehavior = false;
 			this.m_lvAutoType.View = System.Windows.Forms.View.Details;
@@ -1065,7 +1065,7 @@
 			this.m_btnTools.Name = "m_btnTools";
 			this.m_btnTools.Size = new System.Drawing.Size(80, 23);
 			this.m_btnTools.TabIndex = 4;
-			this.m_btnTools.Text = "&Tools";
+			this.m_btnTools.Text = "T&ools";
 			this.m_btnTools.TextImageRelation = System.Windows.Forms.TextImageRelation.ImageBeforeText;
 			this.m_btnTools.UseVisualStyleBackColor = true;
 			this.m_btnTools.Click += new System.EventHandler(this.OnBtnTools);
