@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2019 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -205,18 +205,16 @@ namespace KeePassLib.Security
 		}
 
 		/// <summary>
-		/// Construct a new protected binary data object. Copy the data from
-		/// a <c>XorredBuffer</c> object.
+		/// Construct a new protected binary data object.
+		/// Copy the data from a <c>XorredBuffer</c> object.
 		/// </summary>
 		/// <param name="bEnableProtection">Enable protection or not.</param>
-		/// <param name="xbProtected"><c>XorredBuffer</c> object used to
-		/// initialize the <c>ProtectedBinary</c> object.</param>
-		public ProtectedBinary(bool bEnableProtection, XorredBuffer xbProtected)
+		/// <param name="xb"><c>XorredBuffer</c> object containing the data.</param>
+		public ProtectedBinary(bool bEnableProtection, XorredBuffer xb)
 		{
-			Debug.Assert(xbProtected != null);
-			if(xbProtected == null) throw new ArgumentNullException("xbProtected");
+			if(xb == null) { Debug.Assert(false); throw new ArgumentNullException("xb"); }
 
-			byte[] pb = xbProtected.ReadPlainText();
+			byte[] pb = xb.ReadPlainText();
 			try { Init(bEnableProtection, pb, 0, pb.Length); }
 			finally { if(bEnableProtection) MemUtil.ZeroByteArray(pb); }
 		}
@@ -281,7 +279,7 @@ namespace KeePassLib.Security
 			byte[] pbKey32 = g_pbKey32;
 			if(pbKey32 == null)
 			{
-				pbKey32 = CryptoRandom.Instance.GetRandomBytes(32);
+				pbKey32 = GetRandom32();
 
 				byte[] pbUpd = Interlocked.Exchange<byte[]>(ref g_pbKey32, pbKey32);
 				if(pbUpd != null) pbKey32 = pbUpd;
@@ -343,24 +341,22 @@ namespace KeePassLib.Security
 		}
 
 		/// <summary>
-		/// Read the protected data and return it protected with a sequence
-		/// of bytes generated by a random stream.
+		/// Get the data xorred with bytes from a <c>CryptoRandomStream</c>.
 		/// </summary>
-		/// <param name="crsRandomSource">Random number source.</param>
 		public byte[] ReadXorredData(CryptoRandomStream crsRandomSource)
 		{
-			Debug.Assert(crsRandomSource != null);
-			if(crsRandomSource == null) throw new ArgumentNullException("crsRandomSource");
+			if(crsRandomSource == null) { Debug.Assert(false); throw new ArgumentNullException("crsRandomSource"); }
 
 			byte[] pbData = ReadData();
-			uint uLen = (uint)pbData.Length;
+			int cb = pbData.Length;
 
-			byte[] randomPad = crsRandomSource.GetRandomBytes(uLen);
-			Debug.Assert(randomPad.Length == pbData.Length);
+			byte[] pbPad = crsRandomSource.GetRandomBytes((uint)cb);
+			Debug.Assert(pbPad.Length == cb);
 
-			for(uint i = 0; i < uLen; ++i)
-				pbData[i] ^= randomPad[i];
+			for(int i = 0; i < cb; ++i)
+				pbData[i] ^= pbPad[i];
 
+			MemUtil.ZeroByteArray(pbPad);
 			return pbData;
 		}
 
@@ -418,5 +414,52 @@ namespace KeePassLib.Security
 
 			return bEq;
 		}
+
+		private static byte[] GetRandom32()
+		{
+			// Do not use CryptoRandom here, as it uses ProtectedBinary;
+			// we would have an infinite recursion when trying to
+			// construct a ProtectedBinary object
+			// return CryptoRandom.Instance.GetRandomBytes(32);
+
+			byte[] pbAll = new byte[32 + 16 + 8 + 4];
+			int i = 0;
+
+			try
+			{
+				RNGCryptoServiceProvider rng = new RNGCryptoServiceProvider();
+				byte[] pb = new byte[32];
+				rng.GetBytes(pb);
+
+				Array.Copy(pb, 0, pbAll, i, 32);
+				i += 32;
+
+				MemUtil.ZeroByteArray(pb);
+				// In .NET 2.0, RNGCryptoServiceProvider does not
+				// implement IDisposable; in later .NET versions it does
+				MemUtil.DisposeIfPossible(rng);
+			}
+			catch(Exception) { Debug.Assert(false); }
+
+			try // In case RNGCryptoServiceProvider doesn't work properly
+			{
+				byte[] pb = Guid.NewGuid().ToByteArray();
+				Array.Copy(pb, 0, pbAll, i, 16);
+				i += 16;
+
+				MemUtil.Int64ToBytesEx(DateTime.UtcNow.ToBinary(), pbAll, i);
+				i += 8;
+
+				MemUtil.Int32ToBytesEx(Environment.TickCount, pbAll, i);
+				i += 4;
+			}
+			catch(Exception) { Debug.Assert(false); }
+
+			Debug.Assert(i == pbAll.Length);
+
+			byte[] pbHash = CryptoUtil.HashSha256(pbAll);
+			MemUtil.ZeroByteArray(pbAll);
+			return pbHash;
+		}
 	}
 }
