@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2019 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -469,10 +469,6 @@ namespace KeePassLib.Serialization
 					(lStreams.LastIndexOf(lStreams[i]) == i));
 
 				try { lStreams[i].Close(); }
-				// Unnecessary exception from CryptoStream with
-				// RijndaelManagedTransform when a stream hasn't been
-				// read completely (e.g. incorrect master key)
-				catch(CryptographicException) { }
 				catch(Exception) { Debug.Assert(false); }
 			}
 
