@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2018 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2019 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -302,25 +302,29 @@ namespace KeePass.UI
 				// if(bRtl) tff |= TextFormatFlags.RightToLeft;
 
 				float fFontSize = DpiScaleFloat((12.0f * 96.0f) / g.DpiY, nHeight);
-				Font font = FontUtil.CreateFont(FontFamily.GenericSansSerif,
-					fFontSize, FontStyle.Bold);
-				int txT = (!bRtl ? tx : (nWidth - tx));
-					// - TextRenderer.MeasureText(g, strTitle, font).Width));
-				// g.DrawString(strTitle, font, brush, fx, fy);
-				BannerFactory.DrawText(g, strTitle, txT, ty, font, clrText, bRtl);
-				font.Dispose();
+				using(Font font = FontUtil.CreateFont(FontFamily.GenericSansSerif,
+					fFontSize, FontStyle.Bold))
+				{
+					int txT = (!bRtl ? tx : (nWidth - tx));
+						// - TextRenderer.MeasureText(g, strTitle, font).Width));
+					// g.DrawString(strTitle, font, brush, fx, fy);
+					BannerFactory.DrawText(g, strTitle, txT, ty, font,
+						clrText, bRtl, nWidth);
+				}
 
 				tx += xIcon; // fx
 				ty += xIcon * 2 + 2; // fy
 
 				float fFontSizeSm = DpiScaleFloat((9.0f * 96.0f) / g.DpiY, nHeight);
-				Font fontSmall = FontUtil.CreateFont(FontFamily.GenericSansSerif,
-					fFontSizeSm, FontStyle.Regular);
-				int txL = (!bRtl ? tx : (nWidth - tx));
-					// - TextRenderer.MeasureText(g, strLine, fontSmall).Width));
-				// g.DrawString(strLine, fontSmall, brush, fx, fy);
-				BannerFactory.DrawText(g, strLine, txL, ty, fontSmall, clrText, bRtl);
-				fontSmall.Dispose();
+				using(Font fontSmall = FontUtil.CreateFont(FontFamily.GenericSansSerif,
+					fFontSizeSm, FontStyle.Regular))
+				{
+					int txL = (!bRtl ? tx : (nWidth - tx));
+						// - TextRenderer.MeasureText(g, strLine, fontSmall).Width));
+					// g.DrawString(strLine, fontSmall, brush, fx, fy);
+					BannerFactory.DrawText(g, strLine, txL, ty, fontSmall,
+						clrText, bRtl, nWidth);
+				}
 
 				g.Dispose();
 			}
@@ -344,8 +348,10 @@ namespace KeePass.UI
 		}
 
 		private static void DrawText(Graphics g, string strText, int x,
-			int y, Font font, Color clrForeground, bool bRtl)
+			int y, Font font, Color clrForeground, bool bRtl, int wImg)
 		{
+			if(string.IsNullOrEmpty(strText)) return;
+
 			// With ClearType on, text drawn using Graphics.DrawString
 			// looks better than TextRenderer.DrawText;
 			// https://sourceforge.net/p/keepass/discussion/329220/thread/06ef4466/
@@ -367,7 +373,46 @@ namespace KeePass.UI
 
 				using(StringFormat sf = new StringFormat(sff))
 				{
-					g.DrawString(strText, font, br, x, y, sf);
+					bool bDrawn = false;
+
+					try
+					{
+						if(bRtl) return; // Default draw (in 'finally')
+
+						GraphicsUnit gu = g.PageUnit; // For MeasureString
+						if((gu != GraphicsUnit.Pixel) && (gu != GraphicsUnit.Display))
+						{
+							Debug.Assert(false); // The code below assumes pixels
+							return;
+						}
+
+						int wTextMax = wImg - x - 1; // 1 px free on right
+						if(wTextMax <= 0) { Debug.Assert(false); return; }
+
+						for(int cch = strText.Length; cch > 0; --cch)
+						{
+							string str = StrUtil.CompactString3Dots(strText, cch);
+							int wText = (int)g.MeasureString(str, font).Width;
+
+							if(wText <= 0)
+							{
+								Debug.Assert(false);
+								break; // Default draw (in 'finally')
+							}
+							if(wText <= wTextMax)
+							{
+								g.DrawString(str, font, br, x, y, sf);
+								bDrawn = true;
+								break;
+							}
+						}
+						Debug.Assert(bDrawn); // Even one char too wide?!
+					}
+					catch(Exception) { Debug.Assert(false); }
+					finally
+					{
+						if(!bDrawn) g.DrawString(strText, font, br, x, y, sf);
+					}
 				}
 			}
 		}
