@@ -1,6 +1,6 @@
 /*
   KeePass Password Safe - The Open-Source Password Manager
-  Copyright (C) 2003-2017 Dominik Reichl <dominik.reichl@t-online.de>
+  Copyright (C) 2003-2019 Dominik Reichl <dominik.reichl@t-online.de>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
 
 using System;
 using System.Collections.Generic;
+using System.Diagnostics;
 using System.Text;
 using System.Windows.Forms;
-using System.Diagnostics;
 
 using Microsoft.Win32;
 
@@ -61,13 +61,13 @@ namespace KeePass.Util
 #if DEBUG
 		~SessionLockNotifier()
 		{
-			Debug.Assert(m_bEventsRegistered == false);
+			Debug.Assert(!m_bEventsRegistered);
 		}
 #endif
 
 		public void Install(EventHandler<SessionLockEventArgs> ev)
 		{
-			this.Uninstall();
+			Uninstall();
 
 			try
 			{
